@@ -17,10 +17,11 @@ our @EXPORT_OK = qw(
     is_hash     every    noop        identity
     is_empty    is_sub   flow        eql
     to_pairs    for_each apply       get
-    second      range
+    second      range    pops        pushes
+    shifts      unshifts
 );
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 use constant ARG_PLACE_HOLDER => {};
 
@@ -327,6 +328,30 @@ sub flatten {
     ];
 }
 
+sub pops {
+    my ($array, $val) = @_;
+
+    return pop @{$array};
+}
+
+sub pushes {
+    my ($array, $val) = @_;
+
+    return push @{$array}, $val;
+}
+
+sub shifts {
+    my ($array, $val) = @_;
+
+    return shift @{$array};
+}
+
+sub unshifts {
+    my ($array, $val) = @_;
+
+    return unshift @{$array}, $val;
+}
+
 sub drop {
     my $args     = [@_];
     my $count    = len($args) > 1 ? $args->[0] : 1;
@@ -755,6 +780,25 @@ Flattens array a single level deep.
 
 =cut
 
+=head2 pop / pushes / shifts / unshifts
+
+Works the same as builtin pop / push etc etc, with mutations,
+except it uses references instead of @ lists.
+
+    my $array = [1,2,3];
+
+    pops($array)
+
+    # 1
+
+    my $array = [1,2,3];
+
+    pushes($array, 4);
+
+    # [1,2,3,4]
+
+=cut
+
 =head2 drop
 
 Creates a slice of array with n elements dropped from the beginning.
